==> techne-0.1.tar.gz: techne-0.1/src/fade.c <==
/* Copyright (C) 2009 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <GL/glu.h>
#include "fade.h"

@implementation Fade

-(Fade *) init
{
    self = [super init];
    self->texture = 1;
    
    return self;
}

-(void) cleanup
{
    [super cleanup];

    if (self->delta < self->duration) {
	glMatrixMode (GL_PROJECTION);
	glPushMatrix();
	glLoadIdentity();
	glOrtho (0, 1, 0, 1, -1, 1);

	glMatrixMode (GL_MODELVIEW);
	glLoadIdentity();

	glUseProgramObjectARB (0);
	glDepthMask (GL_FALSE);
    
	glEnable (GL_BLEND);
	glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);

	glColor4f (0, 0, 0, self->delta / self->duration);

	glBegin (GL_QUADS);
	glVertex2f (0, 0);
	glVertex2f (1, 0);
	glVertex2f (1, 1);
	glVertex2f (0, 1);
	glEnd();
    
	glDisable (GL_BLEND);
	glDepthMask(GL_TRUE);

	glMatrixMode (GL_PROJECTION);
	glPopMatrix();
    }
}

@end

==> techne-0.2.1.tar.gz: techne-0.2.1/src/fade.c <==
/* Copyright (C) 2009 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <GL/glu.h>
#include "fade.h"

@implementation Fade

-(Fade *) init
{
    self = [super init];

    /* Avoid creating a texture out of the
       framebuffer during cleanup. */
    
    self->texture = -1;
    
    return self;
}

-(void) finish
{
    [super finish];

    if (self->progress > 0) {
	glMatrixMode (GL_PROJECTION);
	glPushMatrix();
	glLoadIdentity();
	glOrtho (0, 1, 0, 1, -1, 1);

	glMatrixMode (GL_MODELVIEW);
	glPushMatrix ();
	glLoadIdentity();

	glUseProgramObjectARB (0);
	glDepthMask (GL_FALSE);
    
	if (self->progress < 1) {
	    glEnable (GL_BLEND);
	    glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
	}
	
	glColor4d (0, 0, 0, self->progress);

	glBegin (GL_QUADS);
	glVertex2f (0, 0);
	glVertex2f (1, 0);
	glVertex2f (1, 1);
	glVertex2f (0, 1);
	glEnd();
    
	glDisable (GL_BLEND);
	glDepthMask(GL_TRUE);

	glMatrixMode (GL_PROJECTION);
	glPopMatrix();

	glMatrixMode (GL_MODELVIEW);
	glPopMatrix ();
    }
}

@end
